@@ -1,3 +1,7 @@
+"""
+Get observation data from the Archimedes API
+"""
+
 from datetime import datetime
 from typing import Any, Dict, List, Tuple, Union
 
@@ -6,7 +10,7 @@ from cachetools import TTLCache, cached
 
 from archimedes.data.common import get_api_base_url_v2
 from archimedes.utils.api_request import api
-from archimedes.utils.date import datetime_to_iso_format, get_end_date, get_start_date
+from archimedes.utils.date import convert_to_iso_format, get_end_date, get_start_date
 from archimedes.utils.split import get_queries_observation, get_queries_observation_json
 from archimedes.utils.threaded_executor import execute_many
 
@@ -69,8 +73,8 @@ def get(  # pylint:disable=too-many-locals
     if isinstance(price_areas, str):
         price_areas = [price_areas]
 
-    start = datetime_to_iso_format(get_start_date(start))
-    end = datetime_to_iso_format(get_end_date(end))
+    start = convert_to_iso_format(get_start_date(start))
+    end = convert_to_iso_format(get_end_date(end))
 
     include_attributes = kwargs.pop("include_attributes", False)
     include_created_at = kwargs.pop("include_created_at", False)
@@ -202,8 +206,8 @@ def get_latest(
     df = get(
         series_ids=series_ids,
         price_areas=price_areas,
-        start=datetime_to_iso_format(start_dt),
-        end=datetime_to_iso_format(end_dt),
+        start=convert_to_iso_format(start_dt),
+        end=convert_to_iso_format(end_dt),
         access_token=access_token,
     )
 
@@ -270,11 +274,11 @@ def _process_observations(observations: Dict[str, Any]) -> pd.DataFrame:
         attributes = pd.DataFrame(observations.pop("attributes").values.tolist())
         observations = observations.join(attributes)
 
-    columns = [
-        x
-        for x in observations.columns
-        if x not in ["from_dt", "to_dt", "ref_dt", "version", "series_id", "price_area"]
-    ]
+    columns = list(
+        set(observations.columns)
+        - {"from_dt", "to_dt", "ref_dt", "version", "series_id", "price_area"}
+    )
+
     if len(columns) == 1:
         columns = columns[0]
     if not observations.empty:
