@@ -290,7 +290,6 @@ def quantile_average(
     start: Union[str, pd.Timestamp, datetime],
     end: Union[str, pd.Timestamp, datetime],
     price_area: str,
-    ref_price: int,
     ref_dt: Union[str, pd.Timestamp, datetime, None] = None,
     *,
     model_name: Union[str, None] = None,
@@ -304,7 +303,6 @@ def quantile_average(
         start: The first hour to fetch prediction for (inclusive).
         end: The last time to fetch prediction for (inclusive).
         price_area: The name of the price area (eg - 'NO2', 'SE4').
-        ref_price: The reference price in € for price comparison.
         ref_dt: The time of the latest RK data to include in the comparison.
                 If None, the latest available reference date is used.
         model_name: Name of prognosis model name to fetch data from.
@@ -317,7 +315,6 @@ def quantile_average(
         "start": start,
         "end": end,
         "price_area": price_area,
-        "ref_price": ref_price,
         "ref_dt": ref_dt,
         "model_name": model_name,
     }
@@ -328,3 +325,21 @@ def quantile_average(
         **kwargs,
     )
     return pd.DataFrame.from_dict(data)
+
+
+def models(
+    access_token: str = None,
+    **kwargs,
+) -> pd.DataFrame:
+    """
+    Get all model names.
+
+    Parameters:
+        access_token: Access token
+    """
+    data = api.request(
+        f"{get_api_base_url_v3()}/rk_within_day/models",
+        access_token=access_token,
+        **kwargs,
+    )
+    return pd.DataFrame(data)
