@@ -7,9 +7,8 @@ from typing import Dict, List, Union
 
 import numpy as np
 import pandas as pd
-from iteration_utilities import unique_everseen
 
-from archimedes.utils.date import datetime_to_iso_format, get_end_date, get_start_date
+from archimedes.utils.date import convert_to_iso_format, get_end_date, get_start_date
 
 from .config import (
     DEFAULT_NUMBER_OF_SUB_IDS,
@@ -27,6 +26,7 @@ def get_queries(  # pylint:disable=too-many-branches,too-many-locals
     start: Union[str, pd.Timestamp, datetime, None],
     end: Union[str, pd.Timestamp, datetime, None],
     is_json_query: bool,
+    **kwargs,
 ) -> List[Dict]:
     """
     Get split queries
@@ -63,24 +63,30 @@ def get_queries(  # pylint:disable=too-many-branches,too-many-locals
     if sum_approx_response_size_in_bytes < SPLIT_REQUEST_AT_SIZE_BYTES:
         if not is_json_query:
             return [
-                {
-                    "start": datetime_to_iso_format(start),
-                    "end": datetime_to_iso_format(end),
-                    "series_ids": sorted(series_ids),
-                    "price_areas": price_areas,
-                }
+                dict(
+                    {
+                        "start": convert_to_iso_format(start),
+                        "end": convert_to_iso_format(end),
+                        "series_ids": sorted(series_ids),
+                        "price_areas": price_areas,
+                    },
+                    **kwargs,
+                )
             ]
-
+        series_ids = list(dict.fromkeys(series_ids))
         queries = [
-            {
-                "start": datetime_to_iso_format(start),
-                "end": datetime_to_iso_format(end),
-                "series_id": series_id,
-                "price_areas": price_areas,
-            }
+            dict(
+                {
+                    "start": convert_to_iso_format(start),
+                    "end": convert_to_iso_format(end),
+                    "series_id": series_id,
+                    "price_areas": price_areas,
+                },
+                **kwargs,
+            )
             for series_id in series_ids
         ]
-        return list(unique_everseen(queries))
+        return queries
 
     large_series_ids = []
     if not series_metadata.empty:
@@ -91,6 +97,7 @@ def get_queries(  # pylint:disable=too-many-branches,too-many-locals
             ):
                 large_series_ids.append(series_id)
 
+    large_series_ids = list(dict.fromkeys(large_series_ids))
     large_queries = []
     for large_series_id in large_series_ids:
         duration = (end - start).total_seconds() / 2
@@ -105,6 +112,7 @@ def get_queries(  # pylint:disable=too-many-branches,too-many-locals
                     actual_start,
                     actual_end,
                     is_json_query,
+                    **kwargs,
                 )
             )
 
@@ -112,12 +120,15 @@ def get_queries(  # pylint:disable=too-many-branches,too-many-locals
 
     if is_json_query:
         remaining_queries = [
-            {
-                "start": datetime_to_iso_format(start),
-                "end": datetime_to_iso_format(end),
-                "series_id": series_id,
-                "price_areas": price_areas,
-            }
+            dict(
+                {
+                    "start": convert_to_iso_format(start),
+                    "end": convert_to_iso_format(end),
+                    "series_id": series_id,
+                    "price_areas": price_areas,
+                },
+                **kwargs,
+            )
             for series_id in remaining_series_ids
         ]
     else:
@@ -125,12 +136,15 @@ def get_queries(  # pylint:disable=too-many-branches,too-many-locals
             remaining_queries = []
         elif len(remaining_series_ids) == 1:
             remaining_queries = [
-                {
-                    "start": datetime_to_iso_format(start),
-                    "end": datetime_to_iso_format(end),
-                    "series_ids": sorted(remaining_series_ids),
-                    "price_areas": price_areas,
-                }
+                dict(
+                    {
+                        "start": convert_to_iso_format(start),
+                        "end": convert_to_iso_format(end),
+                        "series_ids": sorted(remaining_series_ids),
+                        "price_areas": price_areas,
+                    },
+                    **kwargs,
+                )
             ]
         else:
             if large_queries:
@@ -139,10 +153,16 @@ def get_queries(  # pylint:disable=too-many-branches,too-many-locals
                 # at all. Also, since remaining_queries is a subset of series_ids
                 # without the large queries, it should never lead to infinite recursion.
                 remaining_queries = get_queries(
-                    remaining_series_ids, price_areas, start, end, is_json_query
+                    remaining_series_ids,
+                    price_areas,
+                    start,
+                    end,
+                    is_json_query,
+                    **kwargs,
                 )
             else:
                 remaining_queries = []
+                remaining_series_ids = list(dict.fromkeys(remaining_series_ids))
                 for half_series_ids in np.array_split(np.sort(remaining_series_ids), 2):
                     remaining_queries.extend(
                         get_queries(
@@ -151,10 +171,11 @@ def get_queries(  # pylint:disable=too-many-branches,too-many-locals
                             start,
                             end,
                             is_json_query,
+                            **kwargs,
                         )
                     )
 
-    return list(unique_everseen(large_queries + remaining_queries))
+    return large_queries + remaining_queries
 
 
 def get_queries_observation(
@@ -162,6 +183,7 @@ def get_queries_observation(
     price_areas: List[str],
     start: Union[str, pd.Timestamp, datetime, None],
     end: Union[str, pd.Timestamp, datetime, None],
+    **kwargs,
 ) -> List[Dict]:
     """
     Get split queries
@@ -174,7 +196,7 @@ def get_queries_observation(
     Returns:
         List[Dict]: List of split up queries.
     """
-    return get_queries(series_ids, price_areas, start, end, False)
+    return get_queries(series_ids, price_areas, start, end, False, **kwargs)
 
 
 def get_queries_observation_json(
@@ -182,6 +204,7 @@ def get_queries_observation_json(
     price_areas: List[str],
     start: Union[str, pd.Timestamp, datetime, None],
     end: Union[str, pd.Timestamp, datetime, None],
+    **kwargs,
 ) -> List[Dict]:
     """
     Get split queries
@@ -194,7 +217,7 @@ def get_queries_observation_json(
     Returns:
         List[Dict]: List of split up queries.
     """
-    return get_queries(series_ids, price_areas, start, end, True)
+    return get_queries(series_ids, price_areas, start, end, True, **kwargs)
 
 
 def get_series_metadata(
